@@ -52,6 +52,12 @@
   {:post [(boolean? %)]}
   (instance? java.util.regex.Pattern regexp))
 
+(defn zipper?
+  "Checks to see if the object has zip/make-node metadata on it (confirming it
+to be a zipper."
+  [obj]
+  (contains? (meta obj) :zip/make-node))
+
 ;; ## String utilities
 
 (defn strict-parse-bool
@@ -106,6 +112,33 @@
     (pprint x w)
     (.toString w)))
 
+(defn to-sentence
+  "Join the given strings as they would be listed in a sentence (using an Oxford
+  comma if there are three or more strings).
+  Examples:
+    [\"apple\"] => \"apple\"
+    [\"apple\" \"orange\"] => \"apple and orange\"
+    [\"apple\" \"orange\" \"banana\"] => \"apple, orange, and banana\""
+  [strings]
+  (let [num-strings (count strings)]
+    (cond
+      (empty? strings)
+      ""
+
+      (= num-strings 1)
+      (first strings)
+
+      (= num-strings 2)
+      (str (first strings) " and " (second strings))
+
+      (= num-strings 3)
+      (let [[s0 s1 s2] strings]
+        (str s0 ", " s1 ", and " s2))
+
+      (> num-strings 3)
+      (str (first strings) ", " (to-sentence (rest strings))))))
+
+
 ;; ## I/O
 
 (defn lines
@@ -198,6 +231,27 @@
    :post [(or (number? %) (nil? %))]}
   ((some-fn parse-int parse-float) s))
 
+;; ## Randomness
+
+(defn rand-weighted-selection
+  "Given alternating numeric weights and values, produces a randomly-selected
+  value according to the weights, which should sum to one.  If the weights sum
+  to less than one, then the last value will have its weight adjusted upwards
+  accordingly. If the weights sum to more than one, then values after the
+  cumulative sum of the weights exceeds one will never be selected."
+  [& weights-and-values]
+  {:pre [(even? (count weights-and-values))
+         (every? number? (take-nth 2 weights-and-values))]}
+  (let [weights (take-nth 2 weights-and-values)
+        values (-> (take-nth 2 (drop 1 weights-and-values)) butlast)
+        cutoffs (-> (reductions + weights) butlast)
+        selected? (let [selected-cutoff (rand)]
+                    #(>= % selected-cutoff))
+        selected (filter (comp selected? first)
+                         (map vector cutoffs values))]
+    (if (empty? selected)
+      (last weights-and-values)
+      (-> (first selected) second))))
 
 ;; ## Collection operations
 
@@ -308,6 +362,11 @@
         (when-not (empty? res)
           res)))))
 
+(defn walk-leaves
+  "Walk a map applying a function to all leaf nodes"
+  [m f]
+  (mapvals #(if (map? %) (walk-leaves % f) (f %)) m))
+
 (defn merge-with-key
   "Returns a map that consists of the rest of the maps conj-ed onto
   the first.  If a key `k` occurs in more than one map, the mapping(s)
@@ -908,6 +967,15 @@
            ~expr
            (cond-let ~bindings ~@more))))))
 
+(defmacro while-let
+  "Repeatedly executes body while test expression is true, evaluating the body
+  with binding-form bound to the value of test."
+  [bindings & body]
+  (let [form (first bindings) test (second bindings)]
+    `(loop [~form ~test]
+       (when ~form
+         ~@body
+         (recur ~test)))))
 
 (defmacro some-pred->>
   "When expr does not satisfy pred, threads it into the first form (via ->>),
