@@ -1,4 +1,4 @@
-(def pdb-version "3.1.0")
+(def pdb-version "3.2.0")
 
 (defn deploy-info
   "Generate deployment information from the URL supplied and the username and
@@ -13,6 +13,11 @@
 (def tk-jetty9-version "1.3.1")
 (def ks-version "1.1.0")
 
+(def pdb-jvm-opts
+  (case (System/getProperty "java.specification.version")
+    "1.7" ["-XX:MaxPermSize=200M"]
+    []))
+
 (defproject puppetlabs/puppetdb pdb-version
   :description "Puppet-integrated catalog and fact storage"
 
@@ -76,9 +81,10 @@
                  [honeysql "0.5.2"]
                  [org.clojure/data.xml "0.0.8"]
                  [com.rpl/specter "0.5.7"]
-                 [org.clojure/core.async "0.1.346.0-17112a-alpha"]]
+                 [org.clojure/core.async "0.1.346.0-17112a-alpha"]
+                 [puppetlabs/http-client "0.4.4"]]
 
-  :jvm-opts ["-XX:MaxPermSize=128M"]
+  :jvm-opts ~pdb-jvm-opts
 
   ;;The below test-selectors is basically using the PUPPETDB_DBTYPE
   ;;environment variable to be the test selector.  The selector below
@@ -87,8 +93,8 @@
   ;;(deftest ^{:postgres false} my-test-name...)
 
   :test-selectors {:default (fn [test-var-meta]
-                              (let [dbtype (keyword (or (System/getenv "PUPPETDB_DBTYPE")
-                                                        "hsqldb"))]
+                              (let [dbtype (or (keyword (System/getenv "PUPPETDB_DBTYPE"))
+                                               :postgres)]
                                 (get test-var-meta dbtype true)))}
 
   :repositories [["releases" "http://nexus.delivery.puppetlabs.net/content/repositories/releases/"]
@@ -122,7 +128,8 @@
                                   [puppetlabs/kitchensink ~ks-version :classifier "test"]
                                   [puppetlabs/trapperkeeper-webserver-jetty9 ~tk-jetty9-version :classifier "test"]
                                   [org.flatland/ordered "1.5.2"]
-                                  [org.clojure/test.check "0.5.9"]]}
+                                  [org.clojure/test.check "0.5.9"]
+                                  [environ "1.0.0"]]}
              :ezbake {:dependencies ^:replace [[puppetlabs/puppetdb ~pdb-version]
                                                [org.clojure/tools.nrepl "0.2.3"]]
                       :name "puppetdb"
