@@ -16,7 +16,11 @@
             [schema.core :as s]
             [slingshot.slingshot :refer [throw+]]
             [puppetlabs.puppetdb.schema :as pls]
-            [puppetlabs.puppetdb.utils :as utils]))
+            [puppetlabs.puppetdb.utils :as utils]
+            [puppetlabs.trapperkeeper.core :as tk]
+            [puppetlabs.trapperkeeper.services :refer [service-id service-context]]))
+
+(def default-mq-endpoint "puppetlabs.puppetdb.commands")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Schemas
@@ -71,6 +75,7 @@
   (merge database-config-in
          (all-optional
            {:gc-interval (pls/defaulted-maybe s/Int 60)
+            :dlo-compression-interval s/Int
             :report-ttl (pls/defaulted-maybe String "14d")
             :node-purge-ttl (pls/defaulted-maybe String "0s")
             :node-ttl (pls/defaulted-maybe String "0s")
@@ -102,6 +107,7 @@
   "Schema for parsed/processed database config that includes write database params"
   (merge database-config-out
          {:gc-interval Minutes
+          (s/optional-key :dlo-compression-interval) Minutes
           :report-ttl Period
           :node-purge-ttl Period
           :node-ttl Period}))
@@ -126,14 +132,14 @@
     {:dlo-compression-threshold (pls/defaulted-maybe String "1d")
      :threads (pls/defaulted-maybe s/Int half-the-cores)
      :store-usage s/Int
-     :max-frame-size (pls/defaulted-maybe String "209715200")
+     :max-frame-size (pls/defaulted-maybe s/Int 209715200)
      :temp-usage s/Int}))
 
 (def command-processing-out
   "Schema for parsed/processed command processing config - currently incomplete"
   {:dlo-compression-threshold Period
    :threads s/Int
-   :max-frame-size s/Str
+   :max-frame-size s/Int
    (s/optional-key :store-usage) s/Int
    (s/optional-key :temp-usage) s/Int})
 
@@ -223,6 +229,7 @@
   [config]
   (-> config
       (configure-section :database write-database-config-in write-database-config-out)
+      (update :database #(utils/assoc-when % :dlo-compression-interval (:gc-interval %)))
       configure-read-db
       (configure-section :command-processing command-processing-in command-processing-out)
       configure-puppetdb))
@@ -295,6 +302,8 @@
                      "This is intended to troubleshoot catalog duplication issues and "
                      "not for enabling in production long term.  See the PuppetDB docs "
                      "for more information on this setting."))
+      (log/warn (str "The config item 'catalog-hash-conflict-debugging' is "
+                     "deprecated and will be retired in a future release."))
       (assoc-in config [:global :catalog-hash-debug-dir] debug-dir))
     config))
 
@@ -351,6 +360,14 @@
             (when dashboard-redirect?
               {:puppetlabs.puppetdb.dashboard/dashboard-redirect-service "/"}))))
 
+(defn- add-mq-defaults
+  [config-data]
+  (-> config-data
+      (update-in [:command-processing :mq :address]
+                 #(or % "vm://localhost?jms.prefetchPolicy.all=1&create=false"))
+      (update-in [:command-processing :mq :endpoint]
+                 #(or % default-mq-endpoint))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
 
@@ -374,4 +391,50 @@
       configure-globals
       validate-vardir
       convert-config
-      configure-catalog-debugging))
+      configure-catalog-debugging
+      add-mq-defaults))
+
+(defn foss? [config]
+  (= "puppetdb" (get-in config [:global :product-name])))
+
+(defn pe? [config]
+  (= "pe-puppetdb" (get-in config [:global :product-name])))
+
+(defn update-server [config]
+  (get-in config [:global :update-server]))
+
+(defn mq-endpoint [config]
+  (get-in config [:command-processing :mq :endpoint]))
+
+(defn mq-broker-url
+  "Returns an appropriate ActiveMQ broker URL."
+  [config]
+  (format "%s&wireFormat.maxFrameSize=%s&marshal=true"
+          (get-in config [:command-processing :mq :address])
+          (get-in config [:command-processing :max-frame-size])))
+
+(defn mq-thread-count
+  "Returns the desired number of MQ listener threads."
+  [config]
+  (get-in config [:command-processing :threads]))
+
+(defn mq-dir [config]
+  (str (io/file (get-in config [:global :vardir]) "mq")))
+
+(defn mq-discard-dir [config]
+  (str (io/file (mq-dir config) "discard")))
+
+(defprotocol DefaultedConfig
+  (get-config [this]))
+
+(defn create-defaulted-config-service [config-transform-fn]
+  (tk/service
+   DefaultedConfig
+   [[:ConfigService get-config]]
+   (init [this context]
+         (assoc context :config (config-transform-fn (get-config))))
+   (get-config [this]
+               (:config (service-context this)))))
+
+(def config-service
+  (create-defaulted-config-service process-config!))
