@@ -1,7 +1,8 @@
 (ns puppetlabs.puppetdb.query.population-test
   (:require [puppetlabs.puppetdb.query.population :as pop]
-            [clojure.java.jdbc.deprecated :as sql]
+            [clojure.java.jdbc :as sql]
             [clojure.test :refer :all]
+            [puppetlabs.puppetdb.jdbc :as jdbc]
             [puppetlabs.puppetdb.scf.storage :refer [deactivate-node!]]
             [puppetlabs.puppetdb.scf.storage-utils :as sutils :refer [to-jdbc-varchar-array]]
             [puppetlabs.puppetdb.fixtures :refer :all]
@@ -16,27 +17,27 @@
       (is (= 0 (pop/num-resources))))
 
     (testing "should only count current resources"
-      (sql/insert-records
-       :certnames
-       {:certname "h1"}
-       {:certname "h2"})
+      (jdbc/insert! :certnames
+                    {:certname "h1"}
+                    {:certname "h2"})
 
       (deactivate-node! "h2")
 
-      (sql/insert-records
-       :catalogs
-       {:id 1 :hash (sutils/munge-hash-for-storage "c1") :api_version 1 :catalog_version "1"
-        :certname "h1" :producer_timestamp (to-timestamp (now))}
-       {:id 2 :hash (sutils/munge-hash-for-storage "c2") :api_version 1 :catalog_version "1"
-        :certname "h2" :producer_timestamp (to-timestamp (now))})
+      (jdbc/insert! :catalogs
+                    {:id 1 :hash (sutils/munge-hash-for-storage "c1")
+                     :api_version 1 :catalog_version "1"
+                     :certname "h1" :producer_timestamp (to-timestamp (now))}
+                    {:id 2 :hash (sutils/munge-hash-for-storage "c2")
+                     :api_version 1 :catalog_version "1"
+                     :certname "h2" :producer_timestamp (to-timestamp (now))})
 
-      (sql/insert-records
+      (jdbc/insert!
        :resource_params_cache
        {:resource (sutils/munge-hash-for-storage "01") :parameters nil}
        {:resource (sutils/munge-hash-for-storage "02") :parameters nil}
        {:resource (sutils/munge-hash-for-storage "03") :parameters nil})
 
-      (sql/insert-records
+      (jdbc/insert!
        :catalog_resources
        {:catalog_id 1 :resource (sutils/munge-hash-for-storage "01") :type "Foo" :title "Bar" :exported true :tags (to-jdbc-varchar-array [])}
        ;; c2's resource shouldn'sutils/munge-hash-for-storage t be counted, as they don't correspond to an active node
@@ -57,10 +58,9 @@
       (is (= 0 (pop/num-nodes))))
 
     (testing "should only count active nodes"
-      (sql/insert-records
-       :certnames
-       {:certname "h1"}
-       {:certname "h2"})
+      (jdbc/insert! :certnames
+                    {:certname "h1"}
+                    {:certname "h2"})
 
       (is (= 2 (pop/num-nodes)))
 
@@ -73,12 +73,11 @@
       (is (= 0 (pop/pct-resource-duplication))))
 
     (testing "should equal (total-unique) / total"
-      (sql/insert-records
-       :certnames
-       {:certname "h1"}
-       {:certname "h2"})
+      (jdbc/insert! :certnames
+                    {:certname "h1"}
+                    {:certname "h2"})
 
-      (sql/insert-records
+      (jdbc/insert!
        :catalogs
        {:id 1 :hash (sutils/munge-hash-for-storage "c1") :api_version 1
         :transaction_uuid (sutils/munge-uuid-for-storage "68b08e2a-eeb1-4322-b241-bfdf151d294b")
@@ -87,13 +86,13 @@
         :transaction_uuid (sutils/munge-uuid-for-storage "68b08e2a-eeb1-4322-b241-bfdf151d294b")
         :catalog_version "1" :certname "h2" :producer_timestamp (to-timestamp (now))})
 
-      (sql/insert-records
+      (jdbc/insert!
        :resource_params_cache
        {:resource (sutils/munge-hash-for-storage "01") :parameters nil}
        {:resource (sutils/munge-hash-for-storage "02") :parameters nil}
        {:resource (sutils/munge-hash-for-storage "03") :parameters nil})
 
-      (sql/insert-records
+      (jdbc/insert!
        :catalog_resources
        {:catalog_id 1 :resource  (sutils/munge-hash-for-storage "01") :type "Foo" :title "Bar" :exported true :tags (to-jdbc-varchar-array [])}
        {:catalog_id 2 :resource  (sutils/munge-hash-for-storage "01") :type "Foo" :title "Baz" :exported true :tags (to-jdbc-varchar-array [])}
