@@ -36,6 +36,7 @@
 
 (def json-agg-row (comp h/json-agg h/row-to-json))
 (def supported-fns #{"sum" "avg" "min" "max" "count"})
+(defn jsonb-type [] (if (su/postgres?) :jsonb :text))
 
 (defn hsql-hash-as-str
   [column-keyword]
@@ -85,6 +86,13 @@
                              "report_timestamp" {:type :timestamp
                                                  :queryable? true
                                                  :field :reports.end_time}
+                             "latest_report_hash" {:type :string
+                                                   :queryable? true
+                                                   :field (hsql-hash-as-str
+                                                            :reports.hash)}
+                             "latest_report_status" {:type :string
+                                                     :queryable? true
+                                                     :field :report_statuses.status}
                              "catalog_environment" {:type :string
                                                     :queryable? true
                                                     :field :catalog_environment.environment}
@@ -92,6 +100,18 @@
                                                    :queryable? true
                                                    :field :reports_environment.environment}}
 
+               :relationships {;; Children - direct
+                               "factsets" {:columns ["certname"]}
+                               "reports" {:columns ["certname"]}
+                               "catalogs" {:columns ["certname"]}
+
+                               ;; Children - transitive
+                               "facts" {:columns ["certname"]}
+                               "fact_contents" {:columns ["certname"]}
+                               "events" {:columns ["certname"]}
+                               "edges" {:columns ["certname"]}
+                               "resources" {:columns ["certname"]}}
+
                :selection {:from [:certnames]
                            :left-join [:catalogs
                                        [:= :certnames.certname :catalogs.certname]
@@ -108,6 +128,9 @@
                                        [:environments :catalog_environment]
                                        [:= :catalog_environment.id :catalogs.environment_id]
 
+                                       :report_statuses
+                                       [:= :reports.status_id :report_statuses.id]
+
                                        [:environments :facts_environment]
                                        [:= :facts_environment.id :fs.environment_id]
 
@@ -157,10 +180,25 @@
                            :modifiers [:distinct]
                            :where [:!= :fv.value_type_id 5]}
 
+               :relationships {;; Children - direct
+                               "facts" {:columns ["name"]}
+                               "fact_contents" {:columns ["path"]}}
+
                :source-table "fact_paths"
                :alias "fact_paths"
                :subquery? false}))
 
+(defn fact-names-query
+  []
+  (map->Query {:projections {"name" {:type :string
+                                     :queryable? true
+                                     :field :name}}
+               :selection {:from [[:fact_paths :fp]]
+                           :modifiers [:distinct]}
+               :source-table "fact_paths"
+               :alias "fact_names"
+               :subquery? false}))
+
 (defn facts-query
   "Query structured facts."
   []
@@ -168,7 +206,6 @@
                                      :queryable? false
                                      :query-only? true
                                      :field :fp.path}
-
                              "value" {:type :multi
                                       :queryable? true
                                       :field :fv.value}
@@ -190,6 +227,14 @@
                                             :query-only? true
                                             :queryable? false
                                             :field :fv.value_float}
+                             "value_string" {:type :string
+                                            :query-only? true
+                                            :queryable? false
+                                            :field :fv.value_string}
+                             "value_boolean" {:type :boolean
+                                              :query-only? true
+                                              :queryable? false
+                                              :field :fv.value_boolean}
                              "name" {:type :string
                                      :queryable? true
                                      :field :fp.name}
@@ -214,6 +259,17 @@
                                        [:= :fs.environment_id :env.id]]
                            :where [:= :fp.depth 0]}
 
+               :relationships {;; Parents - direct
+                               "factsets" {:columns ["certname"]}
+
+                               ;; Parents - transitive
+                               "nodes" {:columns ["certname"]}
+                               "environments" {:local-columns ["environment"]
+                                               :foreign-columns ["name"]}
+
+                               ;; Children - direct
+                               "fact_contents" {:columns ["certname" "name"]}}
+
                :alias "facts"
                :source-table "facts"
                :entity :facts
@@ -245,6 +301,14 @@
                                             :queryable? false
                                             :field :fv.value_float
                                             :query-only? true}
+                             "value_string" {:type :string
+                                            :query-only? true
+                                            :queryable? false
+                                            :field :fv.value_string}
+                             "value_boolean" {:type :boolean
+                                              :query-only? true
+                                              :queryable? false
+                                              :field :fv.value_boolean}
                              "type" {:type :string
                                      :queryable? false
                                      :field :vt.type
@@ -266,6 +330,15 @@
                                        [:= :fs.environment_id :env.id]]
                            :where [:!= :fv.value_type_id 5]}
 
+               :relationships {;; Parents - direct
+                               "facts" {:columns ["certname" "name"]}
+                               "factsets" {:columns ["certname"]}
+
+                               ;; Parents - transitive
+                               "nodes" {:columns ["certname"]}
+                               "environments" {:local-columns ["environment"]
+                                               :foreign-columns ["name"]}}
+
                :alias "fact_nodes"
                :source-table "facts"
                :subquery? false}))
@@ -276,7 +349,9 @@
   []
   (map->Query {:projections {"logs" {:type :json
                                      :queryable? false
-                                     :field :reports.logs}
+                                     :field (h/coalesce :logs
+                                                        (h/scast :logs_json
+                                                                 (jsonb-type)))}
                              "hash" {:type :string
                                      :queryable? true
                                      :query-only? true
@@ -294,7 +369,10 @@
   []
   (map->Query {:projections {"metrics" {:type :json
                                         :queryable? false
-                                        :field :reports.metrics}
+                                        :field (h/coalesce :reports.metrics
+                                                           (h/scast
+                                                             :reports.metrics_json
+                                                             (jsonb-type)))}
                              "hash" {:type :string
                                      :queryable? true
                                      :query-only? true
@@ -338,12 +416,17 @@
       "metrics" {:type :json
                  :queryable? false
                  :field {:select [(h/row-to-json :t)]
-                         :from [[{:select [[:metrics :data] [(hsql-hash-as-str :hash) :href]]} :t]]}
+                         :from [[{:select
+                                  [[(h/coalesce :metrics
+                                                (h/scast :metrics_json (jsonb-type))) :data]
+                                           [(hsql-hash-as-str :hash) :href]]} :t]]}
                  :expandable? true}
       "logs" {:type :json
               :queryable? false
               :field {:select [(h/row-to-json :t)]
-                      :from [[{:select [[:logs :data] [(hsql-hash-as-str :hash) :href]]} :t]]}
+                      :from [[{:select [[(h/coalesce :logs
+                                                     (h/scast :logs_json (jsonb-type)))
+                                         :data] [(hsql-hash-as-str :hash) :href]]} :t]]}
               :expandable? true}
       "receive_time"    {:type :timestamp
                          :queryable? true
@@ -384,6 +467,15 @@
                              :report_statuses
                              [:= :reports.status_id :report_statuses.id]]}
 
+     :relationships {;; Parents - direct
+                     "nodes" {:columns ["certname"]}
+                     "environments" {:local-columns ["environment"]
+                                     :foreign-columns ["name"]}
+
+                     ;; Children - direct
+                     "events" {:local-columns ["hash"]
+                               :foreign-columns ["report"]}}
+
      :alias "reports"
      :subquery? false
      :entity :reports
@@ -406,6 +498,9 @@
       "transaction_uuid" {:type :string
                           :queryable? true
                           :field (hsql-uuid-as-str :c.transaction_uuid)}
+      "code_id" {:type :string
+                 :queryable? true
+                 :field :c.code_id}
       "environment" {:type :string
                      :queryable? true
                      :field :e.environment}
@@ -454,6 +549,15 @@
                  :left-join [[:environments :e]
                              [:= :c.environment_id :e.id]]}
 
+     :relationships {;; Parents - direct
+                     "node" {:columns ["certname"]}
+                     "environments" {:local-columns ["environment"]
+                                     :foreign-columns ["name"]}
+
+                     ;; Children - direct
+                     "edges" {:columns ["certname"]}
+                     "resources" {:columns ["certname"]}}
+
      :alias "catalogs"
      :entity :catalogs
      :subquery? false
@@ -494,6 +598,12 @@
                                    [:= :edges.target :targets.resource]
                                    [:= :catalogs.id :targets.catalog_id]]]}
 
+               :relationships {;; Parents - direct
+                               "catalogs" {:columns ["certname"]}
+
+                               ;; Parents - transitive
+                               "nodes" {:columns ["certname"]}}
+
                :alias "edges"
                :subquery? false
                :source-table "edges"}))
@@ -544,6 +654,14 @@
                                        [:resource_params_cache :rpc]
                                        [:= :rpc.resource :resources.resource]]}
 
+               :relationships {;; Parents - direct
+                               "catalogs" {:columns ["certname"]}
+
+                               ;; Parents - transitive
+                               "nodes" {:columns ["certname"]}
+                               "environments" {:local-columns ["environment"]
+                                               :foreign-columns ["name"]}}
+
                :alias "resources"
                :subquery? false
                :source-table "catalog_resources"}))
@@ -617,6 +735,15 @@
                            :left-join [:environments
                                        [:= :reports.environment_id :environments.id]]}
 
+               :relationships {;; Parents - direct
+                               "reports" {:local-columns ["report"]
+                                          :foreign-columns ["hash"]}
+
+                               ;; Parents - transitive
+                               "nodes" {:columns ["certname"]}
+                               "environments" {:local-columns ["environment"]
+                                               :foreign-columns ["name"]}}
+
                :alias "events"
                :subquery? false
                :entity :events
@@ -644,6 +771,24 @@
                                      :field :environment}}
                :selection {:from [:environments]}
 
+               :relationships {;; Children - direct
+                               "factsets" {:local-columns ["name"]
+                                           :foreign-columns ["environment"]}
+                               "catalogs" {:local-columns ["name"]
+                                           :foreign-columns ["environment"]}
+                               "reports" {:local-columns ["name"]
+                                          :foreign-columns ["environment"]}
+
+                               ;; Children - transitive
+                               "facts" {:local-columns ["name"]
+                                        :foreign-columns ["environment"]}
+                               "fact_contents" {:local-columns ["name"]
+                                                :foreign-columns ["environment"]}
+                               "events" {:local-columns ["name"]
+                                         :foreign-columns ["environment"]}
+                               "resources" {:local-columns ["name"]
+                                            :foreign-columns ["environment"]}}
+
                :alias "environments"
                :subquery? false
                :source-table "environments"}))
@@ -687,6 +832,15 @@
                  :left-join [:environments
                              [:= :factsets.environment_id :environments.id]]}
 
+     :relationships {;; Parents - direct
+                     "nodes" {:columns ["certname"]}
+                     "environments" {:local-columns ["environment"]
+                                     :foreign-columns ["name"]}
+
+                     ;; Children - direct
+                     "facts" {:columns ["certname"]}
+                     "fact_contents" {:columns ["certname"]}}
+
      :alias "factsets"
      :entity :factsets
      :source-table "factsets"
@@ -869,11 +1023,18 @@
 ;;;              language
 
 (def user-name->query-rec-name
-  {"select_facts" facts-query
+  {"select_catalogs" catalog-query
+   "select_edges" edges-query
+   "select_environments" environments-query
+   "select_events" report-events-query
+   "select_facts" facts-query
+   "select_factsets" factsets-query
    "select_fact_contents" fact-contents-query
+   "select_fact_paths" fact-paths-query
    "select_nodes" nodes-query
    "select_latest_report" latest-report-query
    "select_params" resource-params-query
+   "select_reports" reports-query
    "select_resources" resources-query})
 
 (defn user-query->logical-obj
@@ -894,6 +1055,11 @@
             [[(op :guard #{"=" "<" ">" "<=" ">="}) "value" (value :guard #(number? %))]]
             ["or" [op "value_integer" value] [op "value_float" value]]
 
+            [[(op :guard #{"="}) "value"
+              (value :guard #(or (string? %) (ks/boolean? %)))]]
+            (let [value-column (if (string? value) "value_string" "value_boolean")]
+            [op value-column value])
+
             [[(op :guard #{"=" "~" ">" "<" "<=" ">="}) "value" value]]
             (when (= :facts (get-in (meta node) [:query-context :entity]))
               ["and" ["=" "depth" 0] [op "value" value]])
@@ -916,14 +1082,15 @@
                 [op "res_param_name" param-name]
                 [op "res_param_value" (su/db-serialize param-value)]]]]]
 
-            [[(op :guard #{"=" "~"}) ["fact" fact-name] (fact-value :guard #(or (string? %)
-                                                                                (instance? Boolean %)))]]
-            ["in" "certname"
-             ["extract" "certname"
-              ["select_facts"
-               ["and"
-                ["=" "name" fact-name]
-                [op "value" fact-value]]]]]
+            [[(op :guard #{"=" "~"}) ["fact" fact-name]
+              (fact-value :guard #(or (string? %) (instance? Boolean %)))]]
+            (let [value-column (if (string? fact-value) "value_string" "value_boolean")]
+              ["in" "certname"
+               ["extract" "certname"
+                ["select_facts"
+                 ["and"
+                  ["=" "name" fact-name]
+                  [op value-column fact-value]]]]])
 
             [[(op :guard #{"=" ">" "<" "<=" ">="}) ["fact" fact-name] fact-value]]
             (if-not (number? fact-value)
@@ -937,6 +1104,19 @@
                    [op "value_float" fact-value]
                    [op "value_integer" fact-value]]]]]])
 
+            [["subquery" sub-entity expr]]
+            (let [relationships (get-in (meta node) [:query-context :relationships sub-entity])]
+              (if relationships
+                (let [{:keys [columns local-columns foreign-columns]} relationships]
+                  (when-not (or columns (and local-columns foreign-columns))
+                    (throw (IllegalArgumentException. (format "Column definition for entity relationship '%s' not valid" sub-entity))))
+                  (do
+                    (log/warn "The `subquery` operator is experimental and may change in the future.")
+                    ["in" (or local-columns columns)
+                     ["extract" (or foreign-columns columns)
+                      [(str "select_" sub-entity) expr]]]))
+                (throw (IllegalArgumentException. (format "No implicit relationship for entity '%s'" sub-entity)))))
+
             [["=" "latest_report?" value]]
             (let [entity (get-in (meta node) [:query-context :entity])
                   expanded-latest (case entity
@@ -1081,10 +1261,11 @@
   (map #(get-in query-rec [:projections % :field]) (sort columns)))
 
 (defn strip-function-calls
-  [column]
-  (let [{functions true nonfunctions false} (group-by #(= "function" (first %)) column)]
-    [(into [] (rest (first functions)))
-     nonfunctions]))
+  [column-or-columns]
+  (let [columns (utils/vector-maybe column-or-columns)
+        {[function-call] true nonfunctions false} (group-by #(= "function" (first %)) columns)]
+    [(vec (rest function-call))
+     (vec nonfunctions)]))
 
 (defn replace-numeric-args
   [fargs]
@@ -1116,11 +1297,6 @@
                                        :column field
                                        :value (facts/factpath-to-string value)})
 
-               :multi
-               (map->BinaryExpression {:operator :=
-                                       :column (hsql-hash-as-str (keyword (str column "_hash")))
-                                       :value (hash/generic-identity-hash value)})
-
                (map->BinaryExpression {:operator :=
                                        :column field
                                        :value value})))
@@ -1179,13 +1355,26 @@
             (map->InExpression {:column (columns->fields query-rec (utils/vector-maybe column))
                                 :subquery (user-node->plan-node query-rec subquery-expression)})
 
-            [["extract" [["function" & fargs]] expr]]
-            (-> query-rec
-                (assoc :call (replace-numeric-args fargs))
-                (create-extract-node [] expr))
+            [["extract" column]]
+            (let [[fargs cols] (strip-function-calls column)
+                  call (replace-numeric-args fargs)
+                  query-rec-with-call (cond-> query-rec
+                                        (not (empty? call)) (assoc :call call))]
+              (create-extract-node query-rec-with-call cols nil))
+
+            [["extract" columns ["group_by" & clauses]]]
+            (let [[fargs cols] (strip-function-calls columns)]
+              (-> query-rec
+                  (assoc :call (replace-numeric-args fargs))
+                  (assoc :group-by clauses)
+                  (create-extract-node cols nil)))
 
             [["extract" column expr]]
-            (create-extract-node query-rec (utils/vector-maybe column) expr)
+            (let [[fargs cols] (strip-function-calls column)
+                  call (replace-numeric-args fargs)
+                  query-rec-with-call (cond-> query-rec
+                                        (not (empty? call)) (assoc :call call))]
+              (create-extract-node query-rec-with-call cols expr))
 
             [["extract" columns expr ["group_by" & clauses]]]
             (let [[fargs cols] (strip-function-calls columns)]
@@ -1263,6 +1452,19 @@
                    :state (cond-> state column-validation-message (conj column-validation-message))
                    :cut true})
 
+                [["subquery" relationship expr]]
+                (let [subquery-expr (push-down-context
+                                     (user-query->logical-obj (str "select_" relationship))
+                                     expr)
+                      nested-qc (:query-context (meta subquery-expr))]
+
+                  {:node (vary-meta ["subquery" relationship
+                                     (vary-meta expr
+                                                assoc :query-context nested-qc)]
+                                    assoc :query-context context)
+                   :state state
+                   :cut true})
+
                 :else
                 (when (instance? clojure.lang.IMeta node)
                   {:node (vary-meta node assoc :query-context context)
@@ -1360,7 +1562,7 @@
   "Given a user provided query and a Query instance, convert the
    user provided query to SQL and extract the parameters, to be used
    in a prepared statement"
-  [query-rec user-query & [{:keys [count?] :as paging-options}]]
+  [query-rec user-query & [{:keys [include_total] :as paging-options}]]
   ;; Call the query-rec so we can evaluate query-rec functions
   ;; which depend on the db connection type
   (let [query-rec (query-rec)
@@ -1376,4 +1578,4 @@
         sql (plan->sql plan)
         paged-sql (jdbc/paged-sql sql paging-options)]
     (cond-> {:results-query (apply vector paged-sql params)}
-      count? (assoc :count-query (apply vector (jdbc/count-sql sql) params)))))
+      include_total (assoc :count-query (apply vector (jdbc/count-sql sql) params)))))
